/* **********************************************************
 * Copyright 2002 VMware, Inc.  All rights reserved. -- VMware Confidential
 * **********************************************************/

#ifndef __VMHOST_H__
#define __VMHOST_H__

#define INCLUDE_ALLOW_MODULE
#include "includeCheck.h"

#include <linux/sched.h>
#include "compat_semaphore.h"
#include "compat_wait.h"

/*
 * Per-vm host-specific state.
 */

typedef struct VMHost {
   /* 
    * Used for shared modifications to VM's VMDriver data, mostly page locking.
    * It has higher rank than the global mutex.
    */
   struct semaphore   vmMutex;

   atomic_t           pendingUserCalls;
   wait_queue_head_t  callQueue;
   volatile Bool      replyWaiting[MAX_INITBLOCK_CPUS];
   wait_queue_head_t  replyQueue[MAX_INITBLOCK_CPUS];
   unsigned int       crosspagePagesCount;
   struct page        *crosspagePages[MAX_INITBLOCK_CPUS];
#ifdef KERNEL_2_4_0
   struct task_struct *vcpuSemaTask[MAX_INITBLOCK_CPUS];
#else
   poll_table         *vcpuSemaWait[MAX_INITBLOCK_CPUS];
#endif
   /*
    * Pages that were allocated/mapped by VMX and locked by the driver and
    * don't have a particular VA. 
    */
   struct PhysTracker *lockedPages;
   /*
    * Locked pages that were allocated by the driver and don't have 
    * a particular VA. They are used as monitor anonymous pages or
    * as pages for "AWE" guest memory.
    */
   struct PhysTracker *AWEPages; 
} VMHost;

#endif
